@@ -119,6 +119,8 @@ def onnx_to_keras(onnx_model, input_names,
                 else:
                     input_shape = [i.dim_value for i in onnx_i.type.tensor_type.shape.dim][1:]
                 dtype = None if input_types is None else input_types[i]
+                if input_shape == [0]:
+                    input_shape = (None,)
                 layers[input_name] = keras.layers.InputLayer(
                     input_shape=input_shape, name=input_name, dtype=dtype
                 ).output
@@ -197,7 +199,10 @@ def onnx_to_keras(onnx_model, input_names,
                         node_params['is_embedding'] = True
                     layers[node_input] = weights[node_input]
                 else:
-                    raise AttributeError('Current node is not in weights / model inputs / layers.')
+                    if node_input == "" and (node_type == 'Pad' or node_type == 'Resize'):
+                        continue
+                    else:
+                        raise AttributeError('Current node is not in weights / model inputs / layers.')
         else:
             logger.debug('... found all, continue')
 
