@@ -29,7 +29,7 @@ def convert_transpose(node, params, layers, lambda_func, node_name, keras_name):
             logger.warning('Transposing numpy array.')
             layers[node_name] = np.transpose(layers[input_name], axes=params['perm'])
         else:
-            raise UnsupportedLayer('Transpose with permute that changes the batch dim')
+            layers[node_name] = tf.transpose(layers[input_name], perm=params['perm'])
     else:
         permute = keras.layers.Permute(params['perm'][1:], name=keras_name)
         layers[node_name] = permute(layers[input_name])
